@@ -28,7 +28,9 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 
 #include "mainwindow.h"
 #include "kanagram_version.h"
@@ -39,9 +41,11 @@ int main(int argc, char **argv)
 {
     QStringList configFiles;
     configFiles << QStringLiteral("kanagramrc");
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrator(QStringLiteral("kanagram"));
     migrator.setConfigFiles(configFiles);
     migrator.migrate();
+#endif
 
     QApplication::setApplicationName(QStringLiteral("kanagram"));
     QApplication::setApplicationVersion(QStringLiteral(KANAGRAM_VERSION_STRING));
@@ -50,9 +54,9 @@ int main(int argc, char **argv)
     KLocalizedString::setApplicationDomain("kanagram");
     QApplication::setApplicationDisplayName(i18n("kanagram"));
 
-    KAboutData about(I18N_NOOP("kanagram"),
+    KAboutData about(i18n("kanagram"),
                      i18n("Kanagram"),
-                     I18N_NOOP(KANAGRAM_VERSION_STRING),
+                     QStringLiteral(KANAGRAM_VERSION_STRING),
                      i18n("An anagram game"),
                      KAboutLicense::GPL,
                      i18n("© 2005 Joshua Keel\n© 2005 Danny Allen\n© 2007 Jeremy Whiting\n© 2014 Debjit Mondal"));
